// page-crm-data.component.ts
import { Component, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { CloudObject, CloudQuery } from '../../../../lib/cloud/ncloud';

@Component({
  selector: 'app-page-crm-data',
  standalone: true,
  imports: [CommonModule, FormsModule],
  templateUrl: './page-crm-data.html', // 确保路径正确
  styleUrls: ['./page-crm-data.scss']
})

export class PageCrmData implements AfterViewInit {
  // 标签相关数据
  // 标签相关数据
sourceTags = [
  { 
    name: '会议记录', 
    active: true, 
    icon: 'calendar-alt',
    type: 'meeting',
    hover: false 
  },
  { 
    name: '客户合同', 
    active: false,
    icon: 'file-signature',
    type: 'contract',
    hover: false 
  },
  { 
    name: '反馈表', 
    active: false,
    icon: 'comment-dots',
    type: 'feedback',
    hover: false 
  },
  { 
    name: '培训资料', 
    active: false,
    icon: 'chalkboard-teacher',
    type: 'training',
    hover: false 
  }
];

// // 处理标签点击
// handleTagClick(tag: any) {
//   if (tag.type) {
//     this.openModal(tag.type);
//   } else {
//     this.selectTag(tag); // 保持原有的selectTag行为
//   }
// }
handleMouseEnter(tag: any) {
  tag.hover = true;
}

handleMouseLeave(tag: any) {
  tag.hover = false;
}

handleTagClick(tag: any) {
  console.log('Tag clicked:', tag);  // 调试输出
  
  this.sourceTags.forEach(t => t.active = false);
  tag.active = true;
  
  if (tag.type) {
    console.log('Opening modal for type:', tag.type);  // 调试输出
    this.openModal(tag.type);
  }
}
  
  newTag = '';
  //7.1
  // 新增模态框相关变量
  showModal: boolean = false;
  modalType: string = '';
  modalTitle: string = '';
  openModal(type: string): void {
    this.modalType = type;
    this.showModal = true;
    
    switch(type) {
      case 'meeting':
        this.modalTitle = '上传会议记录';
        break;
      case 'contract':
        this.modalTitle = '上传客户合同';
        break;
      case 'feedback':
        this.modalTitle = '上传反馈表';
        break;
      case 'training':
        this.modalTitle = '上传培训资料';
        break;
    }
  }
  
  closeModal(): void {
    this.showModal = false;
    this.modalType = '';
    this.modalTitle = '';
  }
  
  confirmUpload(): void {
    // 这里处理上传逻辑
    console.log(`上传${this.modalTitle}确认`);
    
    // 可以添加上传逻辑，然后关闭模态框
    this.closeModal();
    
    // 可以在这里添加上传状态提示
    this.uploadStatus = {
      visible: true,
      success: true,
      message: `${this.modalTitle}上传成功!`,
      progress: 100
    };
    
    // 3秒后隐藏上传状态
    setTimeout(() => {
      this.uploadStatus.visible = false;
    }, 3000);
  }

  //
  // 在PageCrmData类中添加这些属性和方法

// 可用的标签列表
availableTags = [
  { id: 1, name: '会议记录', icon: 'calendar-alt' },
  { id: 2, name: '客户合同', icon: 'file-signature' },
  { id: 3, name: '反馈表', icon: 'comment-dots' },
  { id: 4, name: '培训资料', icon: 'chalkboard-teacher' },
  { id: 5, name: '销售报告', icon: 'chart-line' },
  { id: 6, name: '产品文档', icon: 'file-alt' },
  { id: 7, name: '市场分析', icon: 'chart-pie' },
  { id: 8, name: '客户反馈', icon: 'comments' },
  { id: 9, name: '财务数据', icon: 'money-bill-wave' },
  { id: 10, name: '项目计划', icon: 'project-diagram' },
  { id: 11, name: '技术文档', icon: 'file-code' },
  { id: 12, name: '用户手册', icon: 'book' },
  { id: 13, name: '测试报告', icon: 'vial' },
  { id: 14, name: '设计稿', icon: 'palette' },
  { id: 15, name: '会议音频', icon: 'microphone' },
  // 可以继续添加更多标签...
];

// 选中的标签
selectedTags: any[] = [];

// 控制标签选择器显示
showTagSelector = false;

openTagSelector(event?: Event) {
  if (event) event.stopPropagation();
  this.showModal = false;
  this.showTagSelector = true;
}

closeTagSelector() {
  this.showTagSelector = false;
}

toggleTagSelection(tag: any) {
  const index = this.selectedTags.findIndex(t => t.id === tag.id);
  if (index >= 0) {
    this.selectedTags.splice(index, 1);
  } else {
    this.selectedTags.push({...tag});
  }
}

isTagSelected(tag: any): boolean {
  return this.selectedTags.some(t => t.id === tag.id);
}

confirmTagSelection() {
  if (this.selectedTags.length > 0) {
    this.selectedTags.forEach(tag => {
      if (!this.sourceTags.some(t => t.name === tag.name)) {
        this.sourceTags.push({
          name: tag.name,
          icon: tag.icon,
          active: false,
          type: tag.name.replace(/\s+/g, '-').toLowerCase(),
          hover: false
        });
      }
    });
    this.selectedTags = [];
    this.showTagSelector = false;
  }
}






  // 上传方式
  uploadMethods = [
    { name: '拍照', icon: 'camera', active: false },
    { name: '文件', icon: 'file', active: false },
    { name: '录音', icon: 'microphone', active: false },
    { name: '文本', icon: 'keyboard', active: false }
  ];
  
  // 上传状态
  uploadStatus = {
    visible: false,
    progress: 0,
    message: '',
    success: false
  };

  // 每日数据记录模态框相关
// 每日数据模态框控制
showDailyDataModal = false;  // 控制模态框显示
searchQuery = '';           // 搜索关键词 (与模板中的[(ngModel)]="searchQuery"对应)

// 每日详细数据 (与模板中的filteredDailyData对应)
dailyData = [
  {
    date: '2023-10-01',
    stats: [
      { label: '新增客户', value: '24', trend: '12', trendUp: true },
      { label: '订单量', value: '56', trend: '5', trendUp: true },
      { label: '销售额', value: '¥12,450', trend: '8', trendUp: false },
      { label: '转化率', value: '32%', trend: '2', trendUp: true }
    ]
  },
  {
    date: '2023-10-02',
    stats: [
      { label: '新增客户', value: '18', trend: '5', trendUp: false },
      { label: '订单量', value: '42', trend: '3', trendUp: true },
      { label: '销售额', value: '¥9,870', trend: '6', trendUp: true },
      { label: '转化率', value: '28%', trend: '4', trendUp: false }
    ]
  },
  // 可以添加更多数据...
];

// 获取过滤后的数据 (与模板中的*ngFor="let item of filteredDailyData"对应)
get filteredDailyData() {
  if (!this.searchQuery.trim()) {
    return this.dailyData;
  }
  const query = this.searchQuery.toLowerCase();
  return this.dailyData.filter(item => 
    item.date.includes(query) || 
    item.stats.some(stat => 
      stat.label.toLowerCase().includes(query) || 
      stat.value.toString().toLowerCase().includes(query)
    )
  );
}

// 打开模态框 (与模板中的(click)="openDailyDataModal()"对应)
openDailyDataModal() {
  this.showDailyDataModal = true;
  this.searchQuery = ''; // 重置搜索条件
}

// 关闭模态框 (与模板中的(click)="closeDailyDataModal()"对应)
closeDailyDataModal() {
  this.showDailyDataModal = false;
}

// 搜索方法 (与模板中的(click)="searchDailyData()"对应)
searchDailyData() {
  // 搜索逻辑已经在getter中实现，这里可以添加额外逻辑
  console.log('搜索关键词:', this.searchQuery);
}


// 在组件类中添加
confirmDailyData() {
  // 这里可以添加确认逻辑
  console.log('数据已确认');
  this.closeDailyDataModal();
  
  // 示例：显示确认提示
  this.uploadStatus = {
    visible: true,
    success: true,
    message: '每日数据已确认提交!',
    progress: 100
  };
  
  setTimeout(() => {
    this.uploadStatus.visible = false;
  }, 3000);
}

//数据库
// 在组件类中添加这些方法
// 数据相关属性
allTrainingData: any[] = [];
filteredTrainingData: any[] = [];
currentTrainingItem = new CloudObject('TrainingData');

// 模态框控制

showDataModal = false;
isEditing = false;

// 仪表板数据
dashboardStats = [
  { label: '新增数据', value: 42, trend: 12, trendUp: true, icon: 'file-medical' },
  { label: '处理中', value: 18, trend: 5, trendUp: false, icon: 'cogs' },
  { label: '训练时间', value: '1.8h', trend: 23, trendUp: true, icon: 'clock' },
  { label: '完成率', value: '76%', trend: 8, trendUp: true, icon: 'check-circle' }
];

constructor() {
  this.loadTrainingData();
}

// 加载训练数据
async loadTrainingData() {
  const query = new CloudQuery('TrainingData');
  this.allTrainingData = await query.find();
  this.filteredTrainingData = [...this.allTrainingData];
}

// 打开训练数据模态框
openTrainingDataModal() {
  this.showDailyDataModal = true;
  this.loadTrainingData();
}

// 关闭训练数据模态框
closeTrainingDataModal() {
  this.showDailyDataModal = false;
  this.searchQuery = '';
  this.filteredTrainingData = [...this.allTrainingData];
}

// 搜索训练数据
searchTrainingData() {
  if (!this.searchQuery.trim()) {
    this.filteredTrainingData = [...this.allTrainingData];
    return;
  }
  
  const query = this.searchQuery.toLowerCase();
  this.filteredTrainingData = this.allTrainingData.filter(item => 
    (item.get('title') || '').toLowerCase().includes(query) || 
    (item.get('type') || '').toLowerCase().includes(query)
  );
}

// 准备新增项目
prepareNewItem() {
  this.currentTrainingItem = new CloudObject('TrainingData');
  this.isEditing = false;
  this.showDataModal = true;
}

// 准备编辑项目
prepareEditItem(item: any) {
  this.currentTrainingItem = new CloudObject('TrainingData');
  this.currentTrainingItem.id = item.id;
  this.currentTrainingItem.set(item);
  this.isEditing = true;
  this.showDataModal = true;
}

// 保存训练数据
async saveTrainingItem() {
  await this.currentTrainingItem.save();
  await this.loadTrainingData();
  this.showDataModal = false;
}

// 删除训练数据
async deleteTrainingItem(item: any) {
  const obj = new CloudObject('TrainingData');
  obj.id = item.id;
  await obj.destroy();
  await this.loadTrainingData();
}

// 获取类型名称
getTypeName(type: string): string {
  const typeMap: Record<string, string> = {
    'meeting': '会议记录',
    'contract': '客户合同',
    'feedback': '反馈表',
    'training': '培训资料'
  };
  return typeMap[type] || '未知类型';
}

// 获取类型图标
getTypeIcon(type: string): string {
  const iconMap: Record<string, string> = {
    'meeting': 'calendar-alt',
    'contract': 'file-signature',
    'feedback': 'comment-dots',
    'training': 'chalkboard-teacher'
  };
  return iconMap[type] || 'file-alt';
}


//
  // 历史记录
  historyItems = [
    { name: 'Q3销售报告.pdf', type: 'pdf', size: 4.2, date: '2023-10-15' },
    { name: '客户数据.xlsx', type: 'excel', size: 3.1, date: '2023-10-14' },
    { name: '会议纪要.docx', type: 'word', size: 1.7, date: '2023-10-13' },
    { name: '用户反馈.csv', type: 'csv', size: 2.3, date: '2023-10-12' }
  ];
  
  filteredHistory = [...this.historyItems];
  searchTerm = '';
  
  // 训练结果
  trainingResults = [
    { title: '销售预测模型', time: '2.3小时', status: 'completed', icon: 'brain' },
    { title: '情感分析模型', time: '1.5小时', status: 'training', icon: 'comments' },
    { title: '趋势预测模型', time: '3.1小时', status: 'completed', icon: 'chart-line' },
    { title: '客户服务模型', time: '4.2小时', status: 'error', icon: 'robot' }
  ];
  
  // 数据看板
  // dashboardStats:any = [
  //   { label: '新增数据', value: 42, trend: 12, trendUp: true, icon: 'file-medical' },
  //   { label: '处理中', value: 18, trend: 5, trendUp: false, icon: 'cogs' },
  //   { label: '训练时间', value: '1.8h', trend: 23, trendUp: true, icon: 'clock' },
  //   { label: '完成率', value: '76%', trend: 8, trendUp: true, icon: 'check-circle' }
  // ];
  
  // 选择标签
  selectTag(tag: any) {
    this.sourceTags.forEach(t => t.active = false);
    tag.active = true;
  }
  
  // 添加新标签
  addTag() {
    if (this.newTag.trim()) {
      this.sourceTags.push({
        name: this.newTag.trim(), active: true,
        icon: '',
        type: '',
        hover: false
      });
      this.selectTag(this.sourceTags[this.sourceTags.length - 1]);
      this.newTag = '';
    }
  }
  
  // 选择上传方式
  selectMethod(method: any) {
    this.uploadMethods.forEach(m => m.active = false);
    method.active = true;
  }
  
  // 上传数据
  uploadData() {
    const selectedTag = this.sourceTags.find(t => t.active)?.name || '未知';
    const selectedMethod = this.uploadMethods.find(m => m.active)?.name || '未选择';
    
    this.uploadStatus = {
      visible: true,
      progress: 0,
      message: `正在上传: ${selectedTag} (方式: ${selectedMethod})`,
      success: false
    };
    
    // 模拟上传进度
    const interval = setInterval(() => {
      this.uploadStatus.progress += Math.floor(Math.random() * 10);
      
      if (this.uploadStatus.progress >= 100) {
        this.uploadStatus.progress = 100;
        clearInterval(interval);
        
        // 上传完成
        setTimeout(() => {
          this.uploadStatus.message = `<i class="fas fa-check-circle"></i> 上传成功: ${selectedTag} (方式: ${selectedMethod})`;
          this.uploadStatus.success = true;
          
          // 添加新项目到历史记录
          this.addHistoryItem(selectedTag, selectedMethod);
          
          // 3秒后隐藏状态
          setTimeout(() => {
            this.uploadStatus.visible = false;
          }, 3000);
        }, 500);
      }
    }, 200);
  }
  
  // 添加历史记录
  addHistoryItem(tagName: string, methodName: string) {
    const fileType = this.getFileExtension(methodName);
    
    this.historyItems.unshift({
      name: `${tagName}.${fileType}`,
      type: fileType,
      size: +(Math.random() * 5).toFixed(1),
      date: this.getCurrentDate()
    });
    
    this.filterHistory();
  }
  
  // 获取文件扩展名
  getFileExtension(method: string): string {
    switch(method) {
      case '拍照': return 'jpg';
      case '文件': return 'pdf';
      case '录音': return 'mp3';
      case '文本': return 'txt';
      default: return 'dat';
    }
  }
  
  // 获取当前日期
  getCurrentDate(): string {
    const now = new Date();
    const year = now.getFullYear();
    const month = String(now.getMonth() + 1).padStart(2, '0');
    const day = String(now.getDate()).padStart(2, '0');
    return `${year}-${month}-${day}`;
  }
  
  // 搜索历史记录
  filterHistory() {
    if (!this.searchTerm.trim()) {
      this.filteredHistory = [...this.historyItems];
      return;
    }
    
    const term = this.searchTerm.toLowerCase();
    this.filteredHistory = this.historyItems.filter(item => 
      item.name.toLowerCase().includes(term) || 
      item.type.toLowerCase().includes(term) ||
      item.date.includes(term)
    );
  }
  
  // 随机更新数据看板
  ngAfterViewInit() {
    setInterval(() => {
      this.dashboardStats = this.dashboardStats.map(stat => {
        if (typeof stat.value === 'number') {
          const change = Math.floor(Math.random() * 5) - 2; // -2 到 2 之间的随机数
          const newValue = Math.max(0, stat.value + change);
          return { ...stat, value: newValue };
        }
        return stat;
      });
    }, 5000);
  }
}